package de.bsvrz.sys.funclib.bitctrl.modell;

import java.util.Collection;
import java.util.EventObject;

/**
 * Kapselt die Änderung an einer online änderbaren Menge.
 *
 * @author BitCtrl Systems GmbH, Falko Schumann
 * @see AenderbareMenge
 */
public class MengenEvent extends EventObject {

	private final Collection<? extends SystemObjekt> hinzugefuegt;
	private final Collection<? extends SystemObjekt> entfernt;

	/**
	 * Erzeugt das Ereignis
	 *
	 * @param source
	 *            die Quelle des Ereignisses; die Menge.
	 * @param hinzugefuegt
	 *            die hinzugefügten Objekt.
	 * @param entfernt
	 *            die entfernten Objekte.
	 */
	public MengenEvent(final AenderbareMenge<? extends SystemObjekt> source,
			final Collection<? extends SystemObjekt> hinzugefuegt,
			final Collection<? extends SystemObjekt> entfernt) {
		super(source);

		this.hinzugefuegt = hinzugefuegt;
		this.entfernt = entfernt;
	}

	/**
	 * Gibt die Menge zurück, die sich bei diesem Ereignis geändert hat.
	 *
	 * @return die geänderte Menge.
	 */
	public AenderbareMenge<SystemObjekt> getMenge() {
		return (AenderbareMenge<SystemObjekt>) getSource();
	}

	/**
	 * Gibt die Objekte zurück, die der Menge bei diesem Ereignis hinzugefügt
	 * wurden.
	 *
	 * @return die der Menge hinzugefügten Objekte.
	 */
	public Collection<? extends SystemObjekt> getHinzugefuegt() {
		return hinzugefuegt;
	}

	/**
	 * Gibt die Objekte zurück, die aus der Menge bei diesem Ereignis entfernt
	 * wurden.
	 *
	 * @return die aus der Menge entfernte Objekte.
	 */
	public Collection<? extends SystemObjekt> getEntfernt() {
		return entfernt;
	}

	private static final long serialVersionUID = 1L;

}
