/*
 * Allgemeine Funktionen mit und ohne Datenverteilerbezug
 * Copyright (C) 2007 BitCtrl Systems GmbH
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.sys.funclib.bitctrl.modell.att;

import java.text.DateFormat;
import java.util.Date;

/**
 * Kapselt ein absolutes Zeitstempelattribut eines Datensatzes.
 *
 * @author BitCtrl Systems GmbH, Falko Schuman
 */
public class Zeitstempel implements Comparable<Zeitstempel> {

	private final long time;

	/**
	 * Initialisiert den Zeitstempel mit der aktuellen Zeit.
	 */
	public Zeitstempel() {
		this(System.currentTimeMillis());
	}

	/**
	 * Initialisiert den Zeitstempel.
	 *
	 * @param time
	 *            der Wert des Zeitstempels.
	 */
	public Zeitstempel(final long time) {
		this.time = time;
	}

	/**
	 * Der Zeitstempel in Millisekunden.
	 *
	 * @return der Zeitstempel.
	 */
	public long getTime() {
		return time;
	}

	@Override
	public boolean equals(final Object obj) {
		if (obj == this) {
			return true;
		} else if (obj instanceof Zeitstempel) {
			return compareTo((Zeitstempel) obj) == 0;
		}
		return false;
	}

	@Override
	public int hashCode() {
		return Long.valueOf(getTime()).hashCode();
	}

	@Override
	public int compareTo(final Zeitstempel o) {
		if (getTime() < o.getTime()) {
			return -1;
		} else if (getTime() > o.getTime()) {
			return 1;
		}
		return 0;
	}

	@Override
	public String toString() {
		return DateFormat.getDateTimeInstance().format(new Date(getTime()));
	}

}
